import { DMFile } from './TwitterTypes';
import Conversation, { GlobalConversation } from "./Conversation";
/**
 * Hold all the direct messages contained in a Twitter GDPR archive.
 */
export declare class DMArchive {
    protected me_id: string;
    protected index: {
        [convId: string]: Conversation;
    };
    protected all_messages: GlobalConversation | undefined;
    constructor(me_id: string);
    /** Add a direct message file in current conversation object. */
    add(convs: DMFile): void;
    /** Get a conversation with specific ID. undefined if it does not exists. */
    get(id: string): Conversation;
    /** Test if archive has a conversation with ID {id} */
    has(id: string): boolean;
    /**
     * Get a message by ID
     */
    single(id: string): import("./TwitterTypes").LinkedDirectMessage;
    /**
     * Get a conversation who has all messages in it.
     *
     * Please note that this method is not recommanded (and time-consuming at initialization).
     * Use the real conversations instead.
     *
     * Use cases: Search text in all messages, in every conversation /
     * Show messages in a timeline, without interest of who wrote it
     */
    get dms(): GlobalConversation;
    /** Group conversations */
    get groups(): Conversation[];
    /** Direct (two participants) conversations */
    get directs(): Conversation[];
    /** Array of conversations registered in this archive. */
    get all(): Conversation[];
    /** Message count. */
    get count(): number;
    /** Conversation count. */
    get length(): number;
}
export default DMArchive;
